@@ -5,6 +5,7 @@ import getpass
 import os
 
 from jade.exceptions import InvalidParameter
+from jade.hpc.common import HpcJobStats
 from jade.utils.utils import load_data
 
 
@@ -147,6 +148,16 @@ class HpcManagerInterface(abc.ABC):
 
         """
 
+    @abc.abstractmethod
+    def get_job_stats(self, job_id):
+        """Get stats for job ID.
+
+        Returns
+        -------
+        HpcJobStats
+
+        """
+
     @abc.abstractmethod
     def get_local_scratch(self):
         """Get path to local storage space.
